pub struct Bindings { /* private fields */ }Expand description
Validated generated Rust source and the metadata used to produce it.
Implementations
Sourceimpl Bindings
impl Bindings
pub fn source(&self) -> &str
pub const fn snapshot(&self) -> &Snapshot
Sourcepub fn write_to(&self, path: impl AsRef<Path>) -> Result<(), Error>
pub fn write_to(&self, path: impl AsRef<Path>) -> Result<(), Error>
Write source without changing the file when its content is identical.
Errors
Fails when reading or writing the output file fails.