Bindings

Struct Bindings 

pub struct Bindings { /* private fields */ }
Validated generated Rust source and the metadata used to produce it.

Implementations

Source

impl Bindings

pub fn source(&self) -> &str

pub const fn snapshot(&self) -> &Snapshot

pub fn write_to(&self, path: impl AsRef<Path>) -> Result<(), Error>

Write source without changing the file when its content is identical.

Errors

Fails when reading or writing the output file fails.

pub fn write_to_out_dir(&self, filename: &str) -> Result<PathBuf, Error>

Write source inside Cargo’s OUT_DIR. The filename must be a single path component.

Errors

Fails outside a build script or if the filename or output path is invalid.

pub fn write_snapshot(&self, path: impl AsRef<Path>) -> Result<(), Error>

Export metadata for later offline builds. Call outside build.rs to update a committed snapshot.

Errors

Fails when encoding or writing the snapshot fails.